@@ -7,7 +7,7 @@ from pathlib import Path
 from typing import (Any, Callable, Dict, Generator, Iterator, List, Match,
                     NamedTuple, Optional, Set, Tuple)
 
-from git_machete import utils
+from git_machete import git_config_keys, utils
 from git_machete.constants import (MAX_COUNT_FOR_INITIAL_LOG,
                                    GitFormatPatterns, SyncToRemoteStatuses)
 from git_machete.exceptions import MacheteException
@@ -324,7 +324,7 @@ class GitContext:
         return os.path.join(self.__get_main_git_dir(), *fragments)
 
     def get_git_machete_definition_file_path(self) -> str:
-        use_top_level_machete_file = self.get_boolean_config_attr(key='machete.worktree.useTopLevelMacheteFile',
+        use_top_level_machete_file = self.get_boolean_config_attr(key=git_config_keys.WORKTREE_USE_TOP_LEVEL_MACHETE_FILE,
                                                                   default_value=True)
         return os.path.join(self.__get_main_git_dir() if use_top_level_machete_file else self.__get_worktree_git_dir(), 'machete')
 
@@ -725,7 +725,8 @@ class GitContext:
         remote_branch = self.get_currently_rebased_branch_or_none()
         if remote_branch:
             raise MacheteException(
-                f"Rebase of `{remote_branch}` in progress. Conclude the rebase first with `git rebase --continue` or `git rebase --abort`.")
+                f"Rebase of {utils.bold(remote_branch)} in progress. "
+                f"Conclude the rebase first with `git rebase --continue` or `git rebase --abort`.")
         if self.is_am_in_progress():
             raise MacheteException(
                 "`git am` session in progress. Conclude `git am` first with `git am --continue` or `git am --abort`.")
@@ -748,7 +749,12 @@ class GitContext:
             raise MacheteException("Not currently on any branch")
         return result
 
-    def __get_merge_base(self, hash1: FullCommitHash, hash2: FullCommitHash) -> FullCommitHash:
+    def __get_merge_base_for_commit_hashes(self, hash1: FullCommitHash, hash2: FullCommitHash) -> FullCommitHash:
+        # This if statement is not changing the outcome of the later return, but
+        # it enhances the efficiency of the script. If both hashes are the same,
+        # there is no point running git merge-base.
+        if hash1 == hash2:
+            return hash1
         if hash1 > hash2:
             hash1, hash2 = hash2, hash1
         if not (hash1, hash2) in self.__merge_base_cached:
@@ -775,13 +781,16 @@ class GitContext:
     ) -> bool:
         earlier_hash = self.get_commit_hash_by_revision(earlier_revision)
         later_hash = self.get_commit_hash_by_revision(later_revision)
-        # This if statement is not changing the outcome of the later return, but
-        # it enhances the efficiency of the script. If both hashes are the same,
-        # there is no point running git merge-base.
-        if earlier_hash == later_hash:
-            return True
+        return self.__get_merge_base_for_commit_hashes(earlier_hash, later_hash) == earlier_hash
 
-        return self.__get_merge_base(earlier_hash, later_hash) == earlier_hash
+    def get_merge_base(
+            self,
+            earlier_revision: AnyRevision,
+            later_revision: AnyRevision,
+    ) -> Optional[FullCommitHash]:
+        earlier_hash = self.get_commit_hash_by_revision(earlier_revision)
+        later_hash = self.get_commit_hash_by_revision(later_revision)
+        return self.__get_merge_base_for_commit_hashes(earlier_hash, later_hash)
 
     # Determine if reachable_from, or any ancestors of reachable_from that are NOT ancestors of equivalent_to,
     # contain a tree with identical contents to equivalent_to, indicating that
